/****************************************************************************/
/*                              CoreMP7                                     */
/*                   Copyright: Actel Corporation                           */
/****************************************************************************/
/*                                                                          */
/*                        Module Name : A7S                                 */
/*                                                                          */
/*                         Written by : CM                                  */
/*                         Version : V1.0.1                                 */
/*                                                                          */
/****************************************************************************/
/*                                                                          */
/*                                                                          */
/* Brief Description :                                                      */
/* Timing Shell for Bus Functional Model of CoreMP7                         */
/*                                                                          */
/* Associated files :                                                       */
/*    a7sBFM.v                                                              */
/*                                                                          */
/****************************************************************************/

`timescale 1 ns / 100 ps

 // Define a primitive flip-flop for use in the timing shell

 //---------------------------------------------------------------------
 // primitive module (Dffpr_bfm) state table definition
 // FUNCTION : POSITIVE EDGE TRIGGERED D FLIP-FLOP WITH ACTIVE LOW
 //            ASYNCHRONOUS SET AND CLEAR. CLR PRIORITY WHEN BOTH
 //            SET AND CLEAR ARE LOW ( Q OUTPUT UDP ).
 //            Enable active low.

 //----------------------------------------------------------------------
primitive Dffpr_bfm (Q, D, CLK, CLR, PRE, E, NOTIFIER_REG);
  output Q;
  input  NOTIFIER_REG;
  input  D, CLK, E, CLR, PRE;
  reg Q;

	table

	//  D   CLK   CLR  PRE   E  NOTIFIER_REG  :   Qt  :  Qt+1

	    1   (01)    1   1    0      ?         :   ?   :   1;  // clocked data
	    0   (01)    1   1    0      ?         :   ?   :   0;  // clocked data
	    1   (01)    1   1    x      ?         :   1   :   1;  // clocked data
	    0   (01)    1   1    x      ?         :   0   :   0;
	    0   (01)    1   1    x      ?         :   1   :   x;
	    1   (01)    1   1    x      ?         :   0   :   x;
	    0   (01)    x   1    0      ?         :   ?   :   0;  // pessimism
	    1   (01)    1   x    0      ?         :   ?   :   1;  // pessimism
	    ?    ?      1   x    ?      ?         :   1   :   1;  // pessimism
	    0    ?      1   x    ?      ?         :   x   :   x;  // pessimism
	    ?    ?      1   x    ?      ?         :   0   :   x;
	    ?    ?      x   x    ?      ?         :   ?   :   x;
	    ?    ?      x   0    ?      ?         :   ?   :   x;
	    ?    ?      x   1    ?      ?         :   0   :   0;
	    ?    ?      x   1    ?      ?         :   1   :   x;
	    ?    ?      0   ?    ?      ?         :   ?   :   0;
	    ?    ?      1   0    ?      ?         :   ?   :   1;
	    1   (x1)    1   1    0      ?         :   1   :   1;  // reducing pessimism
	    0   (x1)    1   1    0      ?         :   0   :   0;
	    1   (0x)    1   1    0      ?         :   1   :   1;
     0   (0x)    1   1    0      ?         :   0   :   0;
	    1   (x1)    1   1    x      ?         :   1   :   1;  // reducing pessimism
	    0   (x1)    1   1    x      ?         :   0   :   0;
	    1   (0x)    1   1    x      ?         :   1   :   1;
	    0   (0x)    1   1    x      ?         :   0   :   0;
	    ?  (?1)     1   1    1      ?         :   ?   :   -;  //no action for CE = 1
	    ?  (0x)     1   1    1      ?         :   ?   :   -;  //no action for CE = 1
	    ?   ?       ?   ?    *      ?         :   ?   :   -;
	    ?   (?0)    ?   ?    ?      ?         :   ?   :   -;  // ignore falling clock
	    ?   (1x)    ?   ?    ?      ?         :   ?   :   -;  // ignore falling clock
	    *    ?      ?   ?    ?      ?         :   ?   :   -;  // ignore data edges
	    ?   ?     (?1)  ?    ?      ?         :   ?   :   -;  // ignore the edges on
	    ?   ?       ?  (?1)  ?      ?         :   ?   :   -;  //       set and clear
	    ?   ?       ?   ?    ?      *         :   ?   :   x;

	endtable
endprimitive

module A7S
(
// Inputs
ABORT, // memory abort or bus error
CFGBIGEND, // big/little endian configuration
CLK, // clock
CLKEN, // clock enable
CPA, // coprocessor absent
CPB, // coprocessor busy
DBGBREAK, // EICE breakpoint/watchpoint indicator
DBGEN, // debug enable
DBGEXT, // EICE external input 0
DBGnTRST, // test reset
DBGRQ, // debug request
DBGTCKEN, // test clock enable
DBGTDI, // EICE data in
DBGTMS, // EICE mode select
nFIQ, // interrupt request
nIRQ, // fast interrupt request
nRESET, // reset
RDATA, // read data bus

// Outputs
ADDR, // address bus
CPnI, // not coprocessor instruction
CPnMREQ, // not memory request
CPnOPC, // not op-code fetch
CPnTRANS, // not memory translate
CPSEQ, // sequential address
CPTBIT, // processor in thumb mode
DBGACK, // debug acknowledge
DBGCOMMRX, // EICE communication channel receive
DBGCOMMTX, // EICE communication channel transmit
DBGnEXEC, // not executed
DBGnTDOEN, // not TDO enable
DBGRNG, // EICE rangeout
DBGTDO, // EICE data out
DBGINSTRVALID, // ETM Instruction valid indicator
DMORE, // set when nxt data mem access is followed by a seq data mem access
LOCK, // locked transaction operation
PROT, // indicates code, data or privilege level
SIZE, // memory access width
TRANS, // next transaction type (i, n, s)
WDATA, // write data bus
WRITE // indicates write access
);

// Inputs
input ABORT;
input CFGBIGEND;
input CLK;
input CLKEN;
input DBGTCKEN;
input CPA;
input CPB;
input DBGBREAK;
input DBGEN;
input [1:0] DBGEXT;
input DBGRQ;
input nFIQ;
input nIRQ;
input nRESET;
input DBGnTRST;
input [31:0] RDATA;
input DBGTDI;
input DBGTMS;

// Outputs
output [31:0] ADDR;
output CPSEQ;
output CPTBIT;
output CPnI;
output CPnMREQ;
output CPnOPC;
output CPnTRANS;
output DBGACK;
output DBGCOMMRX;
output DBGCOMMTX;
output [1:0] DBGRNG;
output DBGnEXEC;
output DBGINSTRVALID;
output DMORE;
output LOCK;
output [1:0] PROT;
output [1:0] SIZE;
output DBGTDO;
output DBGnTDOEN;
output [1:0] TRANS;
output [31:0] WDATA;
output WRITE;

wire [31:0] d_ADDR;
wire        d_WRITE;
wire [31:0] d_WDATA;
wire [1:0]  d_SIZE;
wire [1:0]  d_TRANS;
wire [31:0] RDATA_out;

supply1 VCC_0;
supply0 GND_0;

a7sBFM u_a7sBFM
(
// Inputs
.ABORT(ABORT), // memory abort or bus error
.CFGBIGEND(CFGBIGEND), // big/little endian configuration
.CLK(CLK), // clock
.CLKEN(CLKEN), // clock enable
.CPA(CPA), // coprocessor absent
.CPB(CPB), // coprocessor busy
.DBGBREAK(DBGBREAK), // EICE breakpoint/watchpoint indicator
.DBGEN(DBGEN), // debug enable
.DBGEXT(DBGEXT), // EICE external input 0
.DBGnTRST(DBGnTRST), // test reset
.DBGRQ(DBGRQ), // debug request
.DBGTCKEN(DBGTCKEN), // test clock enable
.DBGTDI(DBGTDI), // EICE data in
.DBGTMS(DBGTMS), // EICE mode select
.nFIQ(nFIQ), // interrupt request
.nIRQ(nIRQ), // fast interrupt request
.nRESET(nRESET), // reset
.RDATA(RDATA), // read data bus
// The following five signals come from external primitive FFs
// in order to apply backannotated delays
.SIZE(SIZE), // memory access width
.TRANS(TRANS), // next transaction type (i, n, s)
.WDATA(WDATA), // write data bus
.WRITE(WRITE), //
.ADDR(ADDR), // address bus

// Outputs
.CPnI(CPnI), // not coprocessor instruction
.CPnMREQ(CPnMREQ), // not memory request
.CPnOPC(CPnOPC), // not op-code fetch
.CPnTRANS(CPnTRANS), // not memory translate
.CPSEQ(CPSEQ), // sequential address
.CPTBIT(CPTBIT), // processor in thumb mode
.DBGACK(DBGACK), // debug acknowledge
.DBGCOMMRX(DBGCOMMRX), // EICE communication channel receive
.DBGCOMMTX(DBGCOMMTX), // EICE communication channel transmit
.DBGnEXEC(DBGnEXEC), // not executed
.DBGnTDOEN(DBGnTDOEN), // not TDO enable
.DBGRNG(DBGRNG), // EICE rangeout
.DBGTDO(DBGTDO), // EICE data out
.DBGINSTRVALID(DBGINSTRVALID), // ETM Instruction valid indicator
.DMORE(DMORE), // set when nxt data mem access is followed by a seq data mem access
.LOCK(LOCK), // locked transaction operation
.PROT(PROT), // indicates code, data or privilege level
// The following five signals are clocked by external primitive FFs
// in order to apply backannotated delays
.d_SIZE(d_SIZE), // pre-clocked version of memory access width
.d_TRANS(d_TRANS), // pre-clocked version of next transaction type (i, n, s)
.d_WDATA(d_WDATA), // pre-clocked version of write data bus
.d_ADDR(d_ADDR), // pre-clocked version of address bus
.d_WRITE(d_WRITE) // pre-clocked version of write access signal
);

// All outputs of the BFM that are actually toggled are clocked out.
// The clocking is done by the following flip-flop primitives.

Dffpr_bfm DF_WRITE(WRITE, d_WRITE, CLK, VCC_0, VCC_0, GND_0, GND_0);

Dffpr_bfm DF_ADDR0(ADDR[0], d_ADDR[0], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR1(ADDR[1], d_ADDR[1], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR2(ADDR[2], d_ADDR[2], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR3(ADDR[3], d_ADDR[3], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR4(ADDR[4], d_ADDR[4], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR5(ADDR[5], d_ADDR[5], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR6(ADDR[6], d_ADDR[6], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR7(ADDR[7], d_ADDR[7], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR8(ADDR[8], d_ADDR[8], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR9(ADDR[9], d_ADDR[9], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR10(ADDR[10], d_ADDR[10], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR11(ADDR[11], d_ADDR[11], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR12(ADDR[12], d_ADDR[12], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR13(ADDR[13], d_ADDR[13], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR14(ADDR[14], d_ADDR[14], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR15(ADDR[15], d_ADDR[15], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR16(ADDR[16], d_ADDR[16], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR17(ADDR[17], d_ADDR[17], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR18(ADDR[18], d_ADDR[18], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR19(ADDR[19], d_ADDR[19], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR20(ADDR[20], d_ADDR[20], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR21(ADDR[21], d_ADDR[21], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR22(ADDR[22], d_ADDR[22], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR23(ADDR[23], d_ADDR[23], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR24(ADDR[24], d_ADDR[24], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR25(ADDR[25], d_ADDR[25], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR26(ADDR[26], d_ADDR[26], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR27(ADDR[27], d_ADDR[27], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR28(ADDR[28], d_ADDR[28], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR29(ADDR[29], d_ADDR[29], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR30(ADDR[30], d_ADDR[30], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_ADDR31(ADDR[31], d_ADDR[31], CLK, VCC_0, VCC_0, GND_0, GND_0);

Dffpr_bfm DF_WDATA0(WDATA[0], d_WDATA[0], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA1(WDATA[1], d_WDATA[1], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA2(WDATA[2], d_WDATA[2], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA3(WDATA[3], d_WDATA[3], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA4(WDATA[4], d_WDATA[4], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA5(WDATA[5], d_WDATA[5], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA6(WDATA[6], d_WDATA[6], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA7(WDATA[7], d_WDATA[7], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA8(WDATA[8], d_WDATA[8], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA9(WDATA[9], d_WDATA[9], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA10(WDATA[10], d_WDATA[10], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA11(WDATA[11], d_WDATA[11], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA12(WDATA[12], d_WDATA[12], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA13(WDATA[13], d_WDATA[13], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA14(WDATA[14], d_WDATA[14], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA15(WDATA[15], d_WDATA[15], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA16(WDATA[16], d_WDATA[16], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA17(WDATA[17], d_WDATA[17], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA18(WDATA[18], d_WDATA[18], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA19(WDATA[19], d_WDATA[19], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA20(WDATA[20], d_WDATA[20], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA21(WDATA[21], d_WDATA[21], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA22(WDATA[22], d_WDATA[22], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA23(WDATA[23], d_WDATA[23], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA24(WDATA[24], d_WDATA[24], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA25(WDATA[25], d_WDATA[25], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA26(WDATA[26], d_WDATA[26], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA27(WDATA[27], d_WDATA[27], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA28(WDATA[28], d_WDATA[28], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA29(WDATA[29], d_WDATA[29], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA30(WDATA[30], d_WDATA[30], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_WDATA31(WDATA[31], d_WDATA[31], CLK, VCC_0, VCC_0, GND_0, GND_0);

Dffpr_bfm DF_SIZE0(SIZE[0], d_SIZE[0], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_SIZE1(SIZE[1], d_SIZE[1], CLK, VCC_0, VCC_0, GND_0, GND_0);

Dffpr_bfm DF_TRANS0(TRANS[0], d_TRANS[0], CLK, VCC_0, VCC_0, GND_0, GND_0);
Dffpr_bfm DF_TRANS1(TRANS[1], d_TRANS[1], CLK, VCC_0, VCC_0, GND_0, GND_0);

// Now define the placeholder timing paths, that will be backannotated onto
// during post-layout simulation.

specify

$setup ( posedge CLKEN, posedge CLK, 0.0 );
$setup ( posedge DBGTCKEN, posedge CLK, 0.0 );
$setup ( posedge DBGTDI, posedge CLK, 0.0 );
$setup ( posedge DBGTMS, posedge CLK, 0.0 );
$setup ( posedge CPA, posedge CLK, 0.0 );
$setup ( posedge CPB, posedge CLK, 0.0 );
$setup ( posedge ABORT, posedge CLK, 0.0 );
$setup ( posedge RDATA[0], posedge CLK, 0.0 );
$setup ( posedge RDATA[1], posedge CLK, 0.0 );
$setup ( posedge RDATA[2], posedge CLK, 0.0 );
$setup ( posedge RDATA[3], posedge CLK, 0.0 );
$setup ( posedge RDATA[4], posedge CLK, 0.0 );
$setup ( posedge RDATA[5], posedge CLK, 0.0 );
$setup ( posedge RDATA[6], posedge CLK, 0.0 );
$setup ( posedge RDATA[7], posedge CLK, 0.0 );
$setup ( posedge RDATA[8], posedge CLK, 0.0 );
$setup ( posedge RDATA[9], posedge CLK, 0.0 );
$setup ( posedge RDATA[10], posedge CLK, 0.0 );
$setup ( posedge RDATA[11], posedge CLK, 0.0 );
$setup ( posedge RDATA[12], posedge CLK, 0.0 );
$setup ( posedge RDATA[13], posedge CLK, 0.0 );
$setup ( posedge RDATA[14], posedge CLK, 0.0 );
$setup ( posedge RDATA[15], posedge CLK, 0.0 );
$setup ( posedge RDATA[16], posedge CLK, 0.0 );
$setup ( posedge RDATA[17], posedge CLK, 0.0 );
$setup ( posedge RDATA[18], posedge CLK, 0.0 );
$setup ( posedge RDATA[19], posedge CLK, 0.0 );
$setup ( posedge RDATA[20], posedge CLK, 0.0 );
$setup ( posedge RDATA[21], posedge CLK, 0.0 );
$setup ( posedge RDATA[22], posedge CLK, 0.0 );
$setup ( posedge RDATA[23], posedge CLK, 0.0 );
$setup ( posedge RDATA[24], posedge CLK, 0.0 );
$setup ( posedge RDATA[25], posedge CLK, 0.0 );
$setup ( posedge RDATA[26], posedge CLK, 0.0 );
$setup ( posedge RDATA[27], posedge CLK, 0.0 );
$setup ( posedge RDATA[28], posedge CLK, 0.0 );
$setup ( posedge RDATA[29], posedge CLK, 0.0 );
$setup ( posedge RDATA[30], posedge CLK, 0.0 );
$setup ( posedge RDATA[31], posedge CLK, 0.0 );
$setup ( posedge CFGBIGEND, posedge CLK, 0.0 );
$setup ( posedge DBGBREAK, posedge CLK, 0.0 );
$setup ( posedge DBGnTRST, posedge CLK, 0.0 );
$setup ( posedge DBGRQ , posedge CLK, 0.0 );
$setup ( posedge DBGEXT[0], posedge CLK, 0.0 );
$setup ( posedge DBGEXT[1], posedge CLK, 0.0 );
$setup ( posedge nFIQ, posedge CLK, 0.0 );
$setup ( posedge nIRQ, posedge CLK, 0.0 );

$setup ( negedge CLKEN, posedge CLK, 0.0 );
$setup ( negedge DBGTCKEN, posedge CLK, 0.0 );
$setup ( negedge DBGTDI, posedge CLK, 0.0 );
$setup ( negedge DBGTMS, posedge CLK, 0.0 );
$setup ( negedge CPA, posedge CLK, 0.0 );
$setup ( negedge CPB, posedge CLK, 0.0 );
$setup ( negedge ABORT, posedge CLK, 0.0 );
$setup ( negedge RDATA[0], posedge CLK, 0.0 );
$setup ( negedge RDATA[1], posedge CLK, 0.0 );
$setup ( negedge RDATA[2], posedge CLK, 0.0 );
$setup ( negedge RDATA[3], posedge CLK, 0.0 );
$setup ( negedge RDATA[4], posedge CLK, 0.0 );
$setup ( negedge RDATA[5], posedge CLK, 0.0 );
$setup ( negedge RDATA[6], posedge CLK, 0.0 );
$setup ( negedge RDATA[7], posedge CLK, 0.0 );
$setup ( negedge RDATA[8], posedge CLK, 0.0 );
$setup ( negedge RDATA[9], posedge CLK, 0.0 );
$setup ( negedge RDATA[10], posedge CLK, 0.0 );
$setup ( negedge RDATA[11], posedge CLK, 0.0 );
$setup ( negedge RDATA[12], posedge CLK, 0.0 );
$setup ( negedge RDATA[13], posedge CLK, 0.0 );
$setup ( negedge RDATA[14], posedge CLK, 0.0 );
$setup ( negedge RDATA[15], posedge CLK, 0.0 );
$setup ( negedge RDATA[16], posedge CLK, 0.0 );
$setup ( negedge RDATA[17], posedge CLK, 0.0 );
$setup ( negedge RDATA[18], posedge CLK, 0.0 );
$setup ( negedge RDATA[19], posedge CLK, 0.0 );
$setup ( negedge RDATA[20], posedge CLK, 0.0 );
$setup ( negedge RDATA[21], posedge CLK, 0.0 );
$setup ( negedge RDATA[22], posedge CLK, 0.0 );
$setup ( negedge RDATA[23], posedge CLK, 0.0 );
$setup ( negedge RDATA[24], posedge CLK, 0.0 );
$setup ( negedge RDATA[25], posedge CLK, 0.0 );
$setup ( negedge RDATA[26], posedge CLK, 0.0 );
$setup ( negedge RDATA[27], posedge CLK, 0.0 );
$setup ( negedge RDATA[28], posedge CLK, 0.0 );
$setup ( negedge RDATA[29], posedge CLK, 0.0 );
$setup ( negedge RDATA[30], posedge CLK, 0.0 );
$setup ( negedge RDATA[31], posedge CLK, 0.0 );
$setup ( negedge CFGBIGEND, posedge CLK, 0.0 );
$setup ( negedge DBGBREAK, posedge CLK, 0.0 );
$setup ( negedge DBGnTRST, posedge CLK, 0.0 );
$setup ( negedge DBGRQ , posedge CLK, 0.0 );
$setup ( negedge DBGEXT[0], posedge CLK, 0.0 );
$setup ( negedge DBGEXT[1], posedge CLK, 0.0 );
$setup ( negedge nFIQ, posedge CLK, 0.0 );
$setup ( negedge nIRQ, posedge CLK, 0.0 );
$setup ( negedge nRESET, posedge CLK, 0.0 );
$setup ( posedge nRESET, posedge CLK, 0.0 );

$hold ( posedge CLK, posedge CLKEN, 0.0 );
$hold ( posedge CLK, posedge DBGTCKEN, 0.0 );
$hold ( posedge CLK, posedge DBGTDI, 0.0 );
$hold ( posedge CLK, posedge DBGTMS, 0.0 );
$hold ( posedge CLK, posedge CPA, 0.0 );
$hold ( posedge CLK, posedge CPB, 0.0 );
$hold ( posedge CLK, posedge ABORT, 0.0 );
$hold ( posedge CLK, posedge RDATA[0], 0.0 );
$hold ( posedge CLK, posedge RDATA[1], 0.0 );
$hold ( posedge CLK, posedge RDATA[2], 0.0 );
$hold ( posedge CLK, posedge RDATA[3], 0.0 );
$hold ( posedge CLK, posedge RDATA[4], 0.0 );
$hold ( posedge CLK, posedge RDATA[5], 0.0 );
$hold ( posedge CLK, posedge RDATA[6], 0.0 );
$hold ( posedge CLK, posedge RDATA[7], 0.0 );
$hold ( posedge CLK, posedge RDATA[8], 0.0 );
$hold ( posedge CLK, posedge RDATA[9], 0.0 );
$hold ( posedge CLK, posedge RDATA[10], 0.0 );
$hold ( posedge CLK, posedge RDATA[11], 0.0 );
$hold ( posedge CLK, posedge RDATA[12], 0.0 );
$hold ( posedge CLK, posedge RDATA[13], 0.0 );
$hold ( posedge CLK, posedge RDATA[14], 0.0 );
$hold ( posedge CLK, posedge RDATA[15], 0.0 );
$hold ( posedge CLK, posedge RDATA[16], 0.0 );
$hold ( posedge CLK, posedge RDATA[17], 0.0 );
$hold ( posedge CLK, posedge RDATA[18], 0.0 );
$hold ( posedge CLK, posedge RDATA[19], 0.0 );
$hold ( posedge CLK, posedge RDATA[20], 0.0 );
$hold ( posedge CLK, posedge RDATA[21], 0.0 );
$hold ( posedge CLK, posedge RDATA[22], 0.0 );
$hold ( posedge CLK, posedge RDATA[23], 0.0 );
$hold ( posedge CLK, posedge RDATA[24], 0.0 );
$hold ( posedge CLK, posedge RDATA[25], 0.0 );
$hold ( posedge CLK, posedge RDATA[26], 0.0 );
$hold ( posedge CLK, posedge RDATA[27], 0.0 );
$hold ( posedge CLK, posedge RDATA[28], 0.0 );
$hold ( posedge CLK, posedge RDATA[29], 0.0 );
$hold ( posedge CLK, posedge RDATA[30], 0.0 );
$hold ( posedge CLK, posedge RDATA[31], 0.0 );
$hold ( posedge CLK, posedge CFGBIGEND, 0.0 );
$hold ( posedge CLK, posedge DBGBREAK, 0.0 );
$hold ( posedge CLK, posedge DBGnTRST, 0.0 );
$hold ( posedge CLK, posedge DBGRQ , 0.0 );
$hold ( posedge CLK, posedge DBGEXT[0], 0.0 );
$hold ( posedge CLK, posedge DBGEXT[1], 0.0 );
$hold ( posedge CLK, posedge nFIQ, 0.0 );
$hold ( posedge CLK, posedge nIRQ, 0.0 );

$hold ( posedge CLK, negedge CLKEN, 0.0 );
$hold ( posedge CLK, negedge DBGTCKEN, 0.0 );
$hold ( posedge CLK, negedge DBGTDI, 0.0 );
$hold ( posedge CLK, negedge DBGTMS, 0.0 );
$hold ( posedge CLK, negedge CPA, 0.0 );
$hold ( posedge CLK, negedge CPB, 0.0 );
$hold ( posedge CLK, negedge ABORT, 0.0 );
$hold ( posedge CLK, negedge RDATA[0], 0.0 );
$hold ( posedge CLK, negedge RDATA[1], 0.0 );
$hold ( posedge CLK, negedge RDATA[2], 0.0 );
$hold ( posedge CLK, negedge RDATA[3], 0.0 );
$hold ( posedge CLK, negedge RDATA[4], 0.0 );
$hold ( posedge CLK, negedge RDATA[5], 0.0 );
$hold ( posedge CLK, negedge RDATA[6], 0.0 );
$hold ( posedge CLK, negedge RDATA[7], 0.0 );
$hold ( posedge CLK, negedge RDATA[8], 0.0 );
$hold ( posedge CLK, negedge RDATA[9], 0.0 );
$hold ( posedge CLK, negedge RDATA[10], 0.0 );
$hold ( posedge CLK, negedge RDATA[11], 0.0 );
$hold ( posedge CLK, negedge RDATA[12], 0.0 );
$hold ( posedge CLK, negedge RDATA[13], 0.0 );
$hold ( posedge CLK, negedge RDATA[14], 0.0 );
$hold ( posedge CLK, negedge RDATA[15], 0.0 );
$hold ( posedge CLK, negedge RDATA[16], 0.0 );
$hold ( posedge CLK, negedge RDATA[17], 0.0 );
$hold ( posedge CLK, negedge RDATA[18], 0.0 );
$hold ( posedge CLK, negedge RDATA[19], 0.0 );
$hold ( posedge CLK, negedge RDATA[20], 0.0 );
$hold ( posedge CLK, negedge RDATA[21], 0.0 );
$hold ( posedge CLK, negedge RDATA[22], 0.0 );
$hold ( posedge CLK, negedge RDATA[23], 0.0 );
$hold ( posedge CLK, negedge RDATA[24], 0.0 );
$hold ( posedge CLK, negedge RDATA[25], 0.0 );
$hold ( posedge CLK, negedge RDATA[26], 0.0 );
$hold ( posedge CLK, negedge RDATA[27], 0.0 );
$hold ( posedge CLK, negedge RDATA[28], 0.0 );
$hold ( posedge CLK, negedge RDATA[29], 0.0 );
$hold ( posedge CLK, negedge RDATA[30], 0.0 );
$hold ( posedge CLK, negedge RDATA[31], 0.0 );
$hold ( posedge CLK, negedge CFGBIGEND, 0.0 );
$hold ( posedge CLK, negedge DBGBREAK, 0.0 );
$hold ( posedge CLK, negedge DBGnTRST, 0.0 );
$hold ( posedge CLK, negedge DBGRQ , 0.0 );
$hold ( posedge CLK, negedge DBGEXT[0], 0.0 );
$hold ( posedge CLK, negedge DBGEXT[1], 0.0 );
$hold ( posedge CLK, negedge nFIQ, 0.0 );
$hold ( posedge CLK, negedge nIRQ, 0.0 );
$hold ( posedge CLK, negedge nRESET, 0.0 );
$hold ( posedge CLK, posedge nRESET, 0.0 );

$width(posedge CLK, 0.0, 0);
$width(negedge CLK, 0.0, 0);

endspecify

specify

(posedge CLK => (ADDR[0] +: d_ADDR[0])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[1] +: d_ADDR[1])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[2] +: d_ADDR[2])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[3] +: d_ADDR[3])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[4] +: d_ADDR[4])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[5] +: d_ADDR[5])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[6] +: d_ADDR[6])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[7] +: d_ADDR[7])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[8] +: d_ADDR[8])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[9] +: d_ADDR[9])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[10] +: d_ADDR[10])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[11] +: d_ADDR[11])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[12] +: d_ADDR[12])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[13] +: d_ADDR[13])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[14] +: d_ADDR[14])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[15] +: d_ADDR[15])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[16] +: d_ADDR[16])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[17] +: d_ADDR[17])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[18] +: d_ADDR[18])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[19] +: d_ADDR[19])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[20] +: d_ADDR[20])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[21] +: d_ADDR[21])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[22] +: d_ADDR[22])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[23] +: d_ADDR[23])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[24] +: d_ADDR[24])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[25] +: d_ADDR[25])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[26] +: d_ADDR[26])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[27] +: d_ADDR[27])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[28] +: d_ADDR[28])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[29] +: d_ADDR[29])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[30] +: d_ADDR[30])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (ADDR[31] +: d_ADDR[31])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WRITE +: d_WRITE)) = ((0.1:0.1:0.1), (0.1:0.1:0.1));
(posedge CLK => (SIZE[0] +: d_SIZE[0])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (SIZE[1] +: d_SIZE[1])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[0] +: d_WDATA[0])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[1] +: d_WDATA[1])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[2] +: d_WDATA[2])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[3] +: d_WDATA[3])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[4] +: d_WDATA[4])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[5] +: d_WDATA[5])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[6] +: d_WDATA[6])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[7] +: d_WDATA[7])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[8] +: d_WDATA[8])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[9] +: d_WDATA[9])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[10] +: d_WDATA[10])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[11] +: d_WDATA[11])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[12] +: d_WDATA[12])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[13] +: d_WDATA[13])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[14] +: d_WDATA[14])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[15] +: d_WDATA[15])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[16] +: d_WDATA[16])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[17] +: d_WDATA[17])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[18] +: d_WDATA[18])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[19] +: d_WDATA[19])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[20] +: d_WDATA[20])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[21] +: d_WDATA[21])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[22] +: d_WDATA[22])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[23] +: d_WDATA[23])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[24] +: d_WDATA[24])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[25] +: d_WDATA[25])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[26] +: d_WDATA[26])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[27] +: d_WDATA[27])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[28] +: d_WDATA[28])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[29] +: d_WDATA[29])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[30] +: d_WDATA[30])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (WDATA[31] +: d_WDATA[31])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (PROT[0] +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (PROT[1] +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (TRANS[0] +: d_TRANS[0])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (TRANS[1] +: d_TRANS[1])) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (CPnMREQ +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (CPnOPC +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (CPSEQ +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (CPTBIT +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (CPnTRANS +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (CPnI +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGACK +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGCOMMRX +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGCOMMTX +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGINSTRVALID +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGnEXEC +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGRNG[0] +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGRNG[1] +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGnTDOEN +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DBGTDO +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (DMORE +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);
(posedge CLK => (LOCK +: CLKEN)) = (0.1:0.1:0.1, 0.1:0.1:0.1);

endspecify

endmodule
